@@ -3,7 +3,7 @@
  * events.c
  *	  handles all events - tty and content
  *
- * Portions Copyright (c) 2017-2023 Pavel Stehule
+ * Portions Copyright (c) 2017-2024 Pavel Stehule
  *
  * IDENTIFICATION
  *	  src/inputs.c
@@ -252,11 +252,7 @@ repeat:
 
 #endif
 
-#ifdef DEBUG_PIPE
-
-	fprintf(debug_pipe, "*** keycode: %d, err: %d\n", nced->keycode, errno);
-
-#endif
+	log_row("*** keycode: %d, err: %d", nced->keycode, errno);
 
 	if (errno == EINTR)
 	{
@@ -279,10 +275,20 @@ repeat:
 	{
 		if (nced->keycode == ERR)
 		{
-				nced->keycode = PSPG_NOTASSIGNED_CODE;
+			nced->keycode = PSPG_NOTASSIGNED_CODE;
+
+			/*
+			 * workaround for macos and older ncurses. When ESC is pressed,
+			 * then first iteration returns ESC, and second ERR (insted
+			 * expected OK) due setting ESCDELAY to 1 ms.
+			 */
+
+			if (first_event)
+			{
 				nced->alt = false;
 				nced->ignore_it = true;
 				return true;
+			}
 		}
 
 		if (nced->keycode == KEY_MOUSE)
@@ -330,13 +336,6 @@ repeat:
 		}
 	}
 
-	/*
-	 * Workaround for issue #204. MacOS returns ERR when there are not
-	 * any other activity after ESC in ESCDELAY limit.
-	 */
-	if (nced->keycode == ERR && !first_event && errno == 0)
-		nced->keycode = PSPG_NOTASSIGNED_CODE;
-
 #if PDCURSES
 
 	nced->alt = is_alt(&nced->keycode);
